@@ -7,8 +7,13 @@ sub prepare {
     my $info    = shift;
 
     my $address = $info->{'address'};
-    return(1) if($address && $address =~ /^$RE{'net'}{'IPv4'}/);
-    return(0);
+    return(0) unless($address && $address =~ /^$RE{'net'}{'IPv4'}/);
+    if($address =~ /^$RE{'net'}{'IPv4'}$/){
+        $info->{'impact'} = $info->{'impact'}.' infrastructure' unless($info->{'impact'} =~ /infrastructure/);
+    } else {
+        $info->{'impact'} = $info->{'impact'}.' network' unless($info->{'impact'} =~ /network/);
+    }
+    return(1);
 }
 
 sub convert {
