@@ -5,7 +5,7 @@ sub prepare {
     my $info    = shift;
 
     return(0) unless($info->{'impact'});
-    return(0) unless($info->{'impact'} =~ /(phish)/);
+    return(0) unless($info->{'impact'} =~ /phish/);
     return(1);
 }
 
